summaryrefslogtreecommitdiff
path: root/stack-alloc.c
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 01:59:29 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 01:59:29 +0200
commit8603f38cb2dae562611b0c840c48c9888fb126bf (patch)
treeb4ecf1f13d1550e537a52ed2f459c0df0682e704 /stack-alloc.c
parent78dbbea945ca92d107987feebf4d4c5ad665d41c (diff)
downloadgmp-8603f38cb2dae562611b0c840c48c9888fb126bf.tar.gz
* stack_alloc.c,stack-alloc.h: Change __tmp to __gmp_tmp.
Diffstat (limited to 'stack-alloc.c')
-rw-r--r--stack-alloc.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/stack-alloc.c b/stack-alloc.c
index f36ee68f4..217f39e87 100644
--- a/stack-alloc.c
+++ b/stack-alloc.c
@@ -50,7 +50,7 @@ static tmp_stack *current = &xxx;
/* Allocate a block of exactly <size> bytes. This should only be called
through the TMP_ALLOC macro, which takes care of rounding/alignment. */
void *
-__tmp_alloc (size)
+__gmp_tmp_alloc (size)
unsigned long size;
{
void *this;
@@ -95,19 +95,20 @@ __tmp_alloc (size)
return this;
}
-/* Typically called at function entry. <mark> is assigned so that __tmp_free
- can later be used to reclaim all subsequently allocated storage. */
+/* Typically called at function entry. <mark> is assigned so that
+ __gmp_tmp_free can later be used to reclaim all subsequently allocated
+ storage. */
void
-__tmp_mark (mark)
+__gmp_tmp_mark (mark)
tmp_marker *mark;
{
mark->which_chunk = current;
mark->alloc_point = current->alloc_point;
}
/* Free everything allocated since <mark> was assigned by __tmp_mark */
void
-__tmp_free (mark)
+__gmp_tmp_free (mark)
tmp_marker *mark;
{
while (mark->which_chunk != current)
@@ -95,19 +95,20 @@ __tmp_alloc (size)
mark->alloc_point = current->alloc_point;
}
-/* Free everything allocated since <mark> was assigned by __tmp_mark */
+/* Free everything allocated since <mark> was assigned by __gmp_tmp_mark */
void